![Wooey!](wooey-banner.png)

[![Build Status](https://github.com/wooey/wooey/workflows/Build-and-Test/badge.svg)](https://github.com/wooey/wooey/actions?query=workflow%3ABuild-and-Test)
[![Deploy-To-Pypi](https://github.com/wooey/Wooey/workflows/Deploy-To-Pypi/badge.svg)](https://github.com/wooey/wooey/actions?query=workflow%3ADeploy-To-Pypi)
[![Deploy-To-Docker](https://github.com/wooey/Wooey/workflows/Deploy-To-Docker/badge.svg)](https://github.com/wooey/wooey/actions?query=workflow%3ADeploy-To-Docker)
[![codecov](https://codecov.io/gh/wooey/Wooey/branch/master/graph/badge.svg)](https://codecov.io/gh/wooey/Wooey)
[![Join the chat at https://gitter.im/wooey/Wooey](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/wooey/Wooey?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

Wooey is a simple web interface to run command line Python scripts. Think of it as an easy way to get your scripts up on the web for routine data analysis, file processing, or anything else.

Wooey was envisioned as a system to allow data analysts to be able to easily:
    
    1. Autodocument workflows for data analysis
        (simple model saving).
    2. Enable fellow co-workers with no command line
        experience to utilize python scripts.
    3. Enable the easy wrapping of any program in simple
       python instead of having to use language specific 
       to existing tools such as Galaxy.


For installation and other instructions, check out our [documentation](http://wooey.readthedocs.org) or give Wooey a test drive at our [demo-server](https://wooey.herokuapp.com)!
